@@ -4,7 +4,6 @@ pub(crate) mod num;
 pub(crate) mod record;
 
 use std::{
-    convert::TryFrom,
     io::{self, Write},
     mem,
 };
@@ -245,7 +244,7 @@ fn add_record(
         .reference_sequence_id()
         .map(i32::from)
         .and_then(|id| reference_sequences.get(id as usize))
-        .map(|rs| rs.sequence())
+        .map(|rs| rs.sequence().as_ref())
         .unwrap_or_default();
 
     data_container_builder.add_record(reference_sequence, record)
